Dimensionless numbers
=====================

Functions are provided for the following dimensionless numbers:

* Archimedes number (Ar)
* Biot number (Bi)
* Peclet number (Pe)
* Prandtl number (Pr)
* Pyrolysis number I (Py I)
* Pyrolysis number II (Py II)
* Reynolds number (Re)
* Schmidt number (Sc)
* Sherwood number (Sh)
* Flow regime

Source code
-----------

.. autofunction:: chemics.archimedes

.. autofunction:: chemics.biot

.. autofunction:: chemics.peclet

.. autofunction:: chemics.prandtl

.. autofunction:: chemics.pyrolysis_one

.. autofunction:: chemics.pyrolysis_two

.. autofunction:: chemics.reynolds

.. autofunction:: chemics.schmidt

.. autofunction:: chemics.sherwood

.. autofunction:: chemics.flow_regime
